# TRAPI → Cypher transpiler

[![Test status via GitHub Actions](https://github.com/ranking-agent/reasoner/workflows/test/badge.svg)](https://github.com/ranking-agent/reasoner/actions?query=workflow%3Atest)
[![Code coverage on Codecov](https://codecov.io/gh/ranking-agent/reasoner-transpiler/branch/main/graph/badge.svg)](https://app.codecov.io/gh/ranking-agent/reasoner-transpiler/branch/main)
